@@ -16,5 +16,14 @@
 
 """The Tornado web server and tools."""
 
-version = "2.1.1"
-version_info = (2, 1, 1)
+from __future__ import absolute_import, division, print_function, with_statement
+
+# version is a human-readable version number.
+
+# version_info is a four-tuple for programmatic comparison. The first
+# three numbers are the components of the version number.  The fourth
+# is zero for an official release, positive for a development branch,
+# or negative for a release candidate or beta (after the base version
+# number has been incremented)
+version = "4.4.2"
+version_info = (4, 4, 2, 0)
